---
title: "BH1750FVI"
linkTitle: "BH1750FVI"
weight: 4
description: >
  Rohm Light Sensor
---

## Registers

### Continously H-Resolution Mode2
Start measurement at 0.5lx resolution. Typically 120ms.

### Continuously H-Resolution Mode
Start measurement at 1lx resolution. Typically 120ms.

### Continuously L-Resolution Mode
Start measurement at 4lx resolution. Typically 16ms.

### One Time H-Resolution Mode2
Start measurement at 0.5lx resolution. Typically 120ms.
Power Down after measurement.


### One Time H-Resolution Mode
Start measurement at 1lx resolution. Typically 120ms.
Power Down after measurement.


### One Time L-Resolution Mode
Start measurement at 4lx resolution. Typically 16ms.
Power Down after measurement.


### Power Down
No active state

### Power On
Waiting for measurement command

### Reset
Reset data register value. Not accepted in Power Down mode.

## License
Licensed under [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html#licenseText).

_BH1750FVI version 0.1.0_

_Based on Cyanobyte spec version 0.1.0_

_Generated from Cyanobyte Codegen version 0.1.0_